@@ -14,12 +14,12 @@ module Listen
           :close_write
         ],
         wait_for_delay: 0.1
-      }
+      }.freeze
 
       private
 
       WIKI_URL = 'https://github.com/guard/listen'\
-        '/wiki/Increasing-the-amount-of-inotify-watchers'
+        '/wiki/Increasing-the-amount-of-inotify-watchers'.freeze
 
       INOTIFY_LIMIT_MESSAGE = <<-EOS.gsub(/^\s*/, '')
         FATAL: Listen error: unable to monitor directories for changes.
@@ -27,7 +27,7 @@ module Listen
       EOS
 
       def _configure(directory, &callback)
-        Kernel.require 'rb-inotify'
+        require 'rb-inotify'
         @worker ||= ::INotify::Notifier.new
         @worker.watch(directory.to_s, *options.events, &callback)
       rescue Errno::ENOSPC
@@ -35,7 +35,9 @@ module Listen
       end
 
       def _run
+        Thread.current[:listen_blocking_read_thread] = true
         @worker.run
+        Thread.current[:listen_blocking_read_thread] = false
       end
 
       def _process_event(dir, event)
@@ -50,10 +52,8 @@ module Listen
         if /1|true/ =~ ENV['LISTEN_GEM_SIMULATE_FSEVENT']
           if (event.flags & [:moved_to, :moved_from]) || _dir_event?(event)
             rel_path = path.dirname.relative_path_from(dir).to_s
-            _queue_change(:dir, dir, rel_path, {})
-          else
-            _queue_change(:dir, dir, rel_path, {})
           end
+          _queue_change(:dir, dir, rel_path, {})
           return
         end
 
@@ -97,6 +97,10 @@ module Listen
       def _dir_event?(event)
         event.flags.include?(:isdir)
       end
+
+      def _stop
+        @worker && @worker.close
+      end
     end
   end
 end
